@@ -131,30 +131,33 @@ def test_end_case_delay(capsys):
 
 
 def test_machine_rate_slow():
-    ps1 = PrintState("ps1", "print1")  # execute at second 0
-    ps2 = PrintState("ps1", "print2")  # execute at second 2
+    w1 = WaitState("w1", 0.1) # execute at second 0
+    w2 = WaitState("w2", 0.1) # execute at second 2
     es = DummyState("endState")  # execute at second 4
-    ps1.add_transition_on_success(ps2)
-    ps2.add_transition_on_success(es)
-    exe = Machine("xe", ps1, end_state_ids=["endState"], rate=0.5)
+    w1.add_transition_on_success(w2)
+    w2.add_transition_on_success(es)
+    exe = Machine("xe", w1, end_state_ids=["endState"], rate=0.5)
     start_time = time.time()
     exe.run()
     duration = time.time() - start_time
-    assert 4 == pytest.approx(duration, rel=1e-2)
+    assert pytest.approx(duration, rel=1e-2) == 4
+    assert w1._status == StateStatus.SUCCESS
+    assert w2._status == StateStatus.SUCCESS
 
 
 def test_machine_rate_fast():
-    ps1 = PrintState("ps1", "print1")  # execute at second 0
-    ps2 = PrintState("ps1", "print2")  # execute at second 0.1
+    w1 = WaitState("w1", 0.05) # execute at second 0
+    w2 = WaitState("w2", 0.05) # execute at second 0.1s
     es = DummyState("endState")  # execute at second 0.2
-    ps1.add_transition_on_success(ps2)
-    ps2.add_transition_on_success(es)
-    exe = Machine("xe", ps1, end_state_ids=["endState"], rate=10)
+    w1.add_transition_on_success(w2)
+    w2.add_transition_on_success(es)
+    exe = Machine("xe", w1, end_state_ids=["endState"], rate=10)
     start_time = time.time()
     exe.run()
     duration = time.time() - start_time
-    assert 0.2 == pytest.approx(duration, abs=1e-2)
-
+    assert pytest.approx(duration, abs=1e-2) == 0.2
+    assert w1._status == StateStatus.SUCCESS
+    assert w2._status == StateStatus.SUCCESS
 
 def test_nested_machine(capsys):
 
@@ -248,8 +251,10 @@ def test_debugging_machine(caplog):
     mac = Machine("mac", s1, ["s2"], debug=True, rate=1, logger=logger)
     mac.run()
     assert mac.is_end()
-    assert caplog.records[0].message == "[Base] mac(Machine) -- RUNNING\n  -> s1(WaitState) -- RUNNING"
-    assert caplog.records[1].message == "[Base] mac(Machine) -- RUNNING\n  -> s2(DummyState) -- SUCCESS"
+    assert len(caplog.records) == 3
+    assert caplog.records[0].message == "[Base] mac(Machine) -- RUNNING\n  -> s1(WaitState) -- RUNNING" # This is at t=0
+    assert caplog.records[1].message == "[Base] mac(Machine) -- RUNNING\n  -> s1(WaitState) -- RUNNING" # This is at t=1 
+    assert caplog.records[2].message == "[Base] mac(Machine) -- RUNNING\n  -> s2(DummyState) -- SUCCESS" # At the end
 
 
 def test_interrupt_machine(capsys):
@@ -307,4 +312,4 @@ def test_repeat_node_in_machine():
         assert counter == i*5
         assert exe._curr_state == ds5
     exe.interrupt()
-    assert counter == (5 * 5) + 1
+    assert counter == (5 * 5)
